@@ -1,4 +1,6 @@
 use {
+  aho_corasick::BuildError,
+  futures::lock::Mutex,
   regex::Error as RegexError,
   std::{
     clone::Clone,
@@ -8,10 +10,7 @@ use {
     path::PathBuf,
     sync::Arc,
   },
-  tokio::{
-    sync::{Mutex, Notify},
-    task::JoinError,
-  },
+  tokio::{sync::Notify, task::JoinError},
 };
 
 #[derive(Clone, Debug)]
@@ -19,6 +18,7 @@ pub enum Fail {
   Join,
   Interrupt,
   RegexError(RegexError),
+  BuildError(BuildError),
   ArgumentError(String),
   IO(PathBuf, ErrorKind),
   BadExit(PathBuf, i32),
@@ -48,6 +48,12 @@ impl From<RegexError> for Fail {
   }
 }
 
+impl From<BuildError> for Fail {
+  fn from(e: BuildError) -> Self {
+    Self::BuildError(e)
+  }
+}
+
 pub struct Abort {
   errors: Mutex<Vec<Fail>>,
   rx: Notify,
@@ -56,7 +62,7 @@ pub struct Abort {
 impl Abort {
   pub fn new() -> Arc<Self> {
     Arc::new(Self {
-      errors: Mutex::new(Default::default()),
+      errors: Mutex::new(Vec::default()),
       rx: Notify::new(),
     })
   }
